@@ -1,16 +1,24 @@
 import socket
+import platform
 
 from getmac import get_mac_address
 import httpx
 
+from .getmac_linux_fix import get_linux_mac_from_local_ip
+
 def get_local_ip():
     with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as s:
         s.connect(("google.com", 80))
         local_ip = s.getsockname()[0]
     return local_ip
 
-def get_mac():
-    return get_mac_address(ip=get_local_ip())
+def get_mac(ip_address=get_local_ip()):
+    mac = get_mac_address(ip=ip_address)
+    if mac:
+        return mac
+    elif platform.system() == 'Linux':
+        return get_linux_mac_from_local_ip(ip_address)
+    
 
 def get_public_ip():
     request = httpx.get('http://ip-api.com/json')
@@ -22,4 +30,3 @@ def get_summary():
         'public': get_public_ip(),
         'mac': get_mac()
     }
-
